/*************************************************************************

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

*************************************************************************/

#include <avr/io.h>
#include <util/delay.h>
#include <avr/interrupt.h>
#include <stdio.h>
#include "uart.h"
#include "ns741.h"
#include "spislave.h"


#define BAUD 115200UL      // Baudrate


int main(void)
{
	unsigned int c;
	/* init UART und printf */
	uart_init( UART_BAUD_SELECT(BAUD, F_CPU) );
	
	SPI_init();

	/* enable Interrupts*/
	sei();

	/* Init FM-Transmitter */
	ns741_init();

	/* Set frequency to 88.6MHz(default value) */
	ns741_set_frequency(87500);

	/* Enable Transmission */
	ns741_power(1);
	
	/* Start RDS Transmission */
	ns741_rds_start();  // power must be on
						// else no RDINTs are generated

	/*
	 * Endless loop which changes the RDS program service name
	 * ca. each 2 seconds
	 */

	//CT: 0x1A53CF740, UTC 2006-07-02 (MJD 53918) 15:29:00 +00:00, 
	ns741_rds_set_time(15, 29, 0, DateToMJD(2,7,2006));
	 
	ns741_rds_set_radiotext("Scream & Shout - will.i.am & Britney Spears");

	ns741_rds_set_progname("init st.");

	 
	while(1)
	{
		c = uart_getc();
		
		if (c=='s')
		{
			ns741_stereo(); //stereo

			ns741_rds_set_progname("stereo  ");
			//_delay_ms(10000);
			printf("switch to stereo\n");
			
		} else if (c=='m')
		
		{
			ns741_mono(); //mono

			ns741_rds_set_progname("mono    ");
			//_delay_ms(10000);
			printf("switch to mono\n");
			
		} else if (c=='n')
		
		{
			ns741_mute(); //mute

			ns741_rds_set_progname("mute    ");
			//_delay_ms(10000);
			printf("mute\n");
			
		} else if (c=='u')
		
		{
			ns741_unmute(); //unmute

			ns741_rds_set_progname("unmute  ");
			//_delay_ms(10000);
			printf("unmute\n");
			
		}

		//printf("%c", SPI_WriteRead(0xaa));
		
		//_delay_ms(10000);
		//ns741_rds_set_radiotextplus("Scream & Shout","will.i.am & Britney Spears");
	}
}
